@@ -286,7 +286,7 @@ void setup_swarm(int num_nodes
 	lt::deadline_timer timer(ios);
 
 	lt::error_code ec;
-	int const swarm_id = test_counter();
+	int const swarm_id = unit_test::test_counter();
 	std::string path = save_path(swarm_id, 0);
 
 	// #error implement a storage-free version! no_storage flag
