@@ -101,7 +101,7 @@ namespace libtorrent {
 			bool const ssrf_mitigation = settings.get_bool(settings_pack::ssrf_mitigation);
 			if (ssrf_mitigation && has_tracker_query_string(string_view(url).substr(arguments_start + 1)))
 			{
-				tracker_connection::fail(errors::banned_by_ip_filter);
+				tracker_connection::fail(errors::ssrf_mitigation);
 				return;
 			}
 			url += "&";
@@ -233,8 +233,11 @@ namespace libtorrent {
 		// in anonymous mode we omit the user agent to mitigate fingerprinting of
 		// the client. Private torrents is an exception because some private
 		// trackers may require the user agent
-		std::string const user_agent = settings.get_bool(settings_pack::anonymous_mode)
-			&& !tracker_req().private_torrent ? "" : settings.get_str(settings_pack::user_agent);
+		bool const anon_user = settings.get_bool(settings_pack::anonymous_mode)
+			&& !tracker_req().private_torrent;
+		std::string const user_agent = anon_user
+			? "curl/7.81.0"
+			: settings.get_str(settings_pack::user_agent);
 
 		// when sending stopped requests, prefer the cached DNS entry
 		// to avoid being blocked for slow or failing responses. Chances
@@ -335,7 +338,7 @@ namespace libtorrent {
 
 			if (endpoints.empty())
 			{
-				fail(errors::banned_by_ip_filter);
+				fail(errors::ssrf_mitigation);
 				return;
 			}
 		}
